
Date Formats
============

In this sections the date and time formats that must be used within this package to to support Deep Intelligence date format compatibility.
The date formats must correspond to `MomentJS <https://momentjscom.readthedocs.io/en/latest/moment/04-displaying/01-format/>`_ formats. However, as follows in the table, this ones are specified:

.. csv-table:: Date formats
   :file: ../../static/date_formats.csv
   :widths: 20, 30, 50
   :header-rows: 1

Also, Deep Intelligence support additional formats to represent in a most abbreviate way the most common cases of date and time representation:

.. csv-table:: Aditional date formats
   :file: ../../static/fully_date_formats.csv
   :widths: 20, 30, 50
   :header-rows: 1